# TP2 Admin



## Notes pour création de venv
Pour la créer : python3 -m venv venvTP2ADCO
Pour l'activer : /venvTP2ADCO/venvTP2ADCO$ source bin/activate
Pour la désactiver : on met juste deactivate


##Package à installer : numpy et pytest
Dans un terminal :
pip install numpy
pip install -U pytest
